@@ -1117,32 +1117,37 @@ xb_builder_node_export_helper(XbBuilderNode *self,
 		g_string_append_printf(helper->xml, " %s=\"%s\"", key, val);
 	}
 
-	/* finish the opening tag and add any text if it exists */
-	if (priv->text != NULL) {
-		g_autofree gchar *text = xb_string_xml_escape(priv->text);
-		g_string_append(helper->xml, ">");
-		g_string_append(helper->xml, text);
+	if (helper->flags & XB_NODE_EXPORT_FLAG_COLLAPSE_EMPTY && priv->text == NULL &&
+	    priv->children == NULL) {
+		g_string_append(helper->xml, " />");
 	} else {
-		g_string_append(helper->xml, ">");
-		if (helper->flags & XB_NODE_EXPORT_FLAG_FORMAT_MULTILINE)
-			g_string_append(helper->xml, "\n");
-	}
+		/* finish the opening tag and add any text if it exists */
+		if (priv->text != NULL) {
+			g_autofree gchar *text = xb_string_xml_escape(priv->text);
+			g_string_append(helper->xml, ">");
+			g_string_append(helper->xml, text);
+		} else {
+			g_string_append(helper->xml, ">");
+			if (helper->flags & XB_NODE_EXPORT_FLAG_FORMAT_MULTILINE)
+				g_string_append(helper->xml, "\n");
+		}
 
-	/* recurse deeper */
-	for (guint i = 0; priv->children != NULL && i < priv->children->len; i++) {
-		XbBuilderNode *child = g_ptr_array_index(priv->children, i);
-		helper->level++;
-		if (!xb_builder_node_export_helper(child, helper, error))
-			return FALSE;
-		helper->level--;
-	}
+		/* recurse deeper */
+		for (guint i = 0; priv->children != NULL && i < priv->children->len; i++) {
+			XbBuilderNode *child = g_ptr_array_index(priv->children, i);
+			helper->level++;
+			if (!xb_builder_node_export_helper(child, helper, error))
+				return FALSE;
+			helper->level--;
+		}
 
-	/* add closing tag */
-	if ((helper->flags & XB_NODE_EXPORT_FLAG_FORMAT_INDENT) > 0 && priv->text == NULL) {
-		for (guint i = 0; i < helper->level; i++)
-			g_string_append(helper->xml, "  ");
+		/* add closing tag */
+		if ((helper->flags & XB_NODE_EXPORT_FLAG_FORMAT_INDENT) > 0 && priv->text == NULL) {
+			for (guint i = 0; i < helper->level; i++)
+				g_string_append(helper->xml, "  ");
+		}
+		g_string_append_printf(helper->xml, "</%s>", priv->element);
 	}
-	g_string_append_printf(helper->xml, "</%s>", priv->element);
 
 	/* add any tail if it exists */
 	if (priv->tail != NULL) {
