@@ -408,7 +408,7 @@ xb_builder_func(void)
 
 	/* check size */
 	bytes = xb_silo_get_bytes(silo);
-	g_assert_cmpint(g_bytes_get_size(bytes), ==, 620);
+	g_assert_cmpint(g_bytes_get_size(bytes), ==, 628);
 }
 
 static void
@@ -1079,7 +1079,7 @@ xb_builder_empty_func(void)
 
 	/* check size */
 	bytes = xb_silo_get_bytes(silo);
-	g_assert_cmpint(g_bytes_get_size(bytes), ==, 32);
+	g_assert_cmpint(g_bytes_get_size(bytes), ==, 40);
 
 	/* try to dump */
 	str = xb_silo_to_string(silo, &error);
@@ -1196,6 +1196,28 @@ xb_node_export_func(void)
 	g_assert_cmpstr(xml_collapsed, ==, "<component attr1=\"val1\" attr2=\"val2\" />");
 }
 
+static void
+xb_node_export_collapse_func(void)
+{
+	const gchar *xml = "<components><aaa /><bbb /></components>";
+	g_autofree gchar *xml_collapsed = NULL;
+	g_autoptr(GError) error = NULL;
+	g_autoptr(XbNode) n = NULL;
+	g_autoptr(XbSilo) silo = NULL;
+
+	/* import from XML */
+	silo = xb_silo_new_from_xml(xml, &error);
+	g_assert_no_error(error);
+	g_assert_nonnull(silo);
+
+	/* export collapsed */
+	n = xb_silo_get_root(silo);
+	g_assert_nonnull(n);
+	xml_collapsed = xb_node_export(n, XB_NODE_EXPORT_FLAG_COLLAPSE_EMPTY, &error);
+	g_assert_no_error(error);
+	g_assert_cmpstr(xml_collapsed, ==, xml);
+}
+
 static void
 xb_xpath_parent_subnode_func(void)
 {
@@ -2345,7 +2367,7 @@ xb_builder_node_func(void)
 	xb_builder_node_add_child(component, description);
 
 	/* no text contents */
-	empty = xb_builder_node_new("empty");
+	empty = xb_builder_node_insert(component, "empty", NULL);
 	xb_builder_node_set_text(empty, NULL, -1);
 	xb_builder_node_set_tail(empty, NULL, -1);
 
@@ -2358,7 +2380,10 @@ xb_builder_node_func(void)
 	g_assert_cmpstr(xb_builder_node_get_element(child_by_text), ==, "id");
 
 	/* check the source XML */
-	xml_src = xb_builder_node_export(components, XB_NODE_EXPORT_FLAG_FORMAT_MULTILINE, &error);
+	xml_src = xb_builder_node_export(components,
+					 XB_NODE_EXPORT_FLAG_FORMAT_MULTILINE |
+					     XB_NODE_EXPORT_FLAG_COLLAPSE_EMPTY,
+					 &error);
 	g_assert_no_error(error);
 	g_assert_nonnull(xml_src);
 	g_print("%s", xml_src);
@@ -2368,6 +2393,7 @@ xb_builder_node_func(void)
 			"<icon type=\"stock\">dave</icon>\n"
 			"<description>hello <em>world!</em>    \n"
 			"</description>\n"
+			"<empty />\n"
 			"</component>\n"
 			"</components>\n",
 			==,
@@ -2379,7 +2405,10 @@ xb_builder_node_func(void)
 	g_assert_nonnull(silo);
 
 	/* check the XML */
-	xml = xb_silo_export(silo, XB_NODE_EXPORT_FLAG_INCLUDE_SIBLINGS, &error);
+	xml = xb_silo_export(silo,
+			     XB_NODE_EXPORT_FLAG_INCLUDE_SIBLINGS |
+				 XB_NODE_EXPORT_FLAG_COLLAPSE_EMPTY,
+			     &error);
 	g_assert_no_error(error);
 	g_assert_nonnull(xml);
 	g_print("%s", xml);
@@ -2389,6 +2418,7 @@ xb_builder_node_func(void)
 			"<icon type=\"stock\">dave</icon>"
 			"<description>hello <em>world!</em>"
 			"</description>"
+			"<empty />"
 			"</component>"
 			"</components>",
 			==,
@@ -2904,6 +2934,7 @@ main(int argc, char **argv)
 	g_test_add_func("/libxmlb/stack{peek}", xb_stack_peek_func);
 	g_test_add_func("/libxmlb/node{data}", xb_node_data_func);
 	g_test_add_func("/libxmlb/node{export}", xb_node_export_func);
+	g_test_add_func("/libxmlb/node{export-collapse}", xb_node_export_collapse_func);
 	g_test_add_func("/libxmlb/builder", xb_builder_func);
 	g_test_add_func("/libxmlb/builder{comments}", xb_builder_comments_func);
 	g_test_add_func("/libxmlb/builder{native-lang}", xb_builder_native_lang_func);
