@@ -23,10 +23,11 @@ typedef struct __attribute__((packed)) {
 	guint16 strtab_ntags;
 	guint8 padding[2];
 	guint32 strtab;
+	guint64 filesz;
 } XbSiloHeader;
 
 #define XB_SILO_MAGIC_BYTES 0x624c4d58
-#define XB_SILO_VERSION	    0x00000008
+#define XB_SILO_VERSION	    0x00000009
 
 typedef struct {
 	/*< private >*/
@@ -60,10 +61,6 @@ XbSiloNode *
 xb_silo_get_child_node(XbSilo *self, XbSiloNode *n, GError **error) G_GNUC_NON_NULL(1, 2);
 const gchar *
 xb_silo_get_node_element(XbSilo *self, XbSiloNode *n, GError **error) G_GNUC_NON_NULL(1, 2);
-const gchar *
-xb_silo_get_node_text(XbSilo *self, XbSiloNode *n, GError **error) G_GNUC_NON_NULL(1, 2);
-const gchar *
-xb_silo_get_node_tail(XbSilo *self, XbSiloNode *n, GError **error) G_GNUC_NON_NULL(1, 2);
 XbSiloNodeAttr *
 xb_silo_get_node_attr_by_str(XbSilo *self, XbSiloNode *n, const gchar *name)
     G_GNUC_NON_NULL(1, 2, 3);
